==> nextcloud-20.0.12.tgz: nextcloud/apps/files_external/l10n/ia.js <==
OC.L10N.register(
    "files_external",
    {
    "External storage" : "Immagazinage externe",
    "Personal" : "Personal",
    "System" : "Systema",
    "Grant access" : "Conceder accesso",
    "Error configuring OAuth1" : "Error durante configuration de OAuth1",
    "Please provide a valid app key and secret." : "Per favor, provide un clave e un secreto ambe valide.",
    "Error configuring OAuth2" : "Error durante configuration de OAuth2",
    "Generate keys" : "Generar claves",
    "Error generating key pair" : "Error durante creation de par de claves",
    "All users. Type to select user or group." : "Tote usatores. Scribe pro selectionar usator o gruppo.",
    "Enable encryption" : "Activar cryptographia",
    "Enable previews" : "Activar previsualisationes",
    "Enable sharing" : "Activar compartimento",
    "Check for changes" : "Verificar nove modificationes",
    "Never" : "Nunquam",
    "Once every direct access" : "A cata accesso directe",
    "Delete" : "Deler",
    "Saved" : "Salveguardate",
    "Save" : "Salveguardar",
    "External mount error" : "Error del montage externe",
    "external-storage" : "immagazinage-externe",
    "Username" : "Nomine de usator",
    "Password" : "Contrasigno",
    "Credentials saved" : "Datos de authentication salveguardate",
    "Credentials saving failed" : "Salveguarda de datos de authentication falleva",
    "Credentials required" : "Datos de authentication requirite",
    "Invalid mount point" : "Puncto de montage non valide",
    "Insufficient data: %s" : "Datos insufficiente: %s",
    "%s" : "%s",
    "Access key" : "Clave de accesso",
    "Secret key" : "Clave secrete",
    "None" : "Nulle",
    "OAuth1" : "OAuth1",
    "App key" : "Clave del Application",
    "App secret" : "Secreto del Application",
    "OAuth2" : "OAuth2",
    "Domain" : "Dominio",
    "API key" : "Clave API",
    "Global credentials" : "Datos de authentication global",
    "Username and password" : "Nomine de usator e contrasigno",
    "RSA public key" : "Clave public RSA",
    "Public key" : "Clave public",
    "Amazon S3" : "Amazon S3",
    "Hostname" : "Nomine de Hospite",
    "Port" : "Porto",
    "Region" : "Region",
    "Enable SSL" : "Activar SSL",
    "Enable Path Style" : "Activar Stilo de Sentiero",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Sub-dossier remote",
    "Secure https://" : "Secur https://",
    "FTP" : "FTP",
    "Host" : "Hospite",
    "Secure ftps://" : "Secure ftps://",
    "Local" : "Local",
    "Location" : "Loco",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "Share" : "Compartir",
    "Show hidden files" : "Monstrar files occultate",
    "Service name" : "Nomine del servicio",
    "Name" : "Nomine",
    "Storage type" : "Typo de immagazinage",
    "Open documentation" : "Aperir documentation",
    "Folder name" : "Nomine de dossier",
    "Authentication" : "Authentication",
    "Configuration" : "Configuration",
    "Available for" : "Disponibile a",
    "Add storage" : "Adder immagazinage",
    "Advanced settings" : "Configurationes avantiate",
    "Allow users to mount external storage" : "Permitter usatores montar immagazinage externe",
    "External storages" : "Immagazinages externe",
    "(group)" : "(gruppo)",
    "SMB / CIFS" : "SMB / CIFS"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.2.tgz: nextcloud/apps/files_external/l10n/ia.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Immagazinages externe",
    "Personal" : "Personal",
    "System" : "Systema",
    "Grant access" : "Conceder accesso",
    "Error configuring OAuth1" : "Error durante configuration de OAuth1",
    "Please provide a valid app key and secret." : "Per favor, provide un clave e un secreto ambe valide.",
    "Error configuring OAuth2" : "Error durante configuration de OAuth2",
    "Generate keys" : "Generar claves",
    "Error generating key pair" : "Error durante creation de par de claves",
    "All users. Type to select user or group." : "Tote usatores. Scribe pro selectionar usator o gruppo.",
    "Enable encryption" : "Activar cryptographia",
    "Enable previews" : "Activar previsualisationes",
    "Enable sharing" : "Activar compartimento",
    "Check for changes" : "Verificar nove modificationes",
    "Never" : "Nunquam",
    "Once every direct access" : "A cata accesso directe",
    "Delete" : "Deler",
    "Saved" : "Salveguardate",
    "Save" : "Salveguardar",
    "External mount error" : "Error del montage externe",
    "external-storage" : "immagazinage-externe",
    "Username" : "Nomine de usator",
    "Password" : "Contrasigno",
    "Credentials saved" : "Datos de authentication salveguardate",
    "Credentials saving failed" : "Salveguarda de datos de authentication falleva",
    "Credentials required" : "Datos de authentication requirite",
    "Invalid mount point" : "Puncto de montage non valide",
    "Insufficient data: %s" : "Datos insufficiente: %s",
    "%s" : "%s",
    "Access key" : "Clave de accesso",
    "Secret key" : "Clave secrete",
    "None" : "Nulle",
    "OAuth1" : "OAuth1",
    "App key" : "Clave del Application",
    "App secret" : "Secreto del Application",
    "OAuth2" : "OAuth2",
    "Domain" : "Dominio",
    "API key" : "Clave API",
    "Global credentials" : "Datos de authentication global",
    "Username and password" : "Nomine de usator e contrasigno",
    "RSA public key" : "Clave public RSA",
    "Public key" : "Clave public",
    "Amazon S3" : "Amazon S3",
    "Hostname" : "Nomine de Hospite",
    "Port" : "Porto",
    "Region" : "Region",
    "Enable SSL" : "Activar SSL",
    "Enable Path Style" : "Activar Stilo de Sentiero",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Sub-dossier remote",
    "Secure https://" : "Secur https://",
    "FTP" : "FTP",
    "Host" : "Hospite",
    "Secure ftps://" : "Secure ftps://",
    "Local" : "Local",
    "Location" : "Loco",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Compartir",
    "Show hidden files" : "Monstrar files occultate",
    "Service name" : "Nomine del servicio",
    "Name" : "Nomine",
    "Storage type" : "Typo de immagazinage",
    "Open documentation" : "Aperir documentation",
    "Folder name" : "Nomine de dossier",
    "External storage" : "Immagazinage externe",
    "Authentication" : "Authentication",
    "Configuration" : "Configuration",
    "Available for" : "Disponibile a",
    "Add storage" : "Adder immagazinage",
    "Advanced settings" : "Configurationes avantiate",
    "Allow users to mount external storage" : "Permitter usatores montar immagazinage externe",
    "(group)" : "(gruppo)"
},
"nplurals=2; plural=(n != 1);");
